#
# spec file for package perl-Carp-Always
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Carp-Always
Version:        0.16
Release:        17.1
%define cpan_name Carp-Always
Summary:        Warns and dies noisily with stack backtraces
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Carp-Always/
Source0:        https://cpan.metacpan.org/authors/id/F/FE/FERREIRA/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::Base)
%{perl_requires}

%description
This module is meant as a debugging aid. It can be used to make a script
complain loudly with stack backtraces when warn()ing or die()ing.

Here are how stack backtraces produced by this module looks:

  # it works for explicit die's and warn's
  $ perl -MCarp::Always -e 'sub f { die "arghh" }; sub g { f }; g'
  arghh at -e line 1
          main::f() called at -e line 1
          main::g() called at -e line 1

  # it works for interpreter-thrown failures
  $ perl -MCarp::Always -w -e 'sub f { $a = shift; @a = @$a };' \
                           -e 'sub g { f(undef) }; g'
  Use of uninitialized value in array dereference at -e line 1
          main::f('undef') called at -e line 2
          main::g() called at -e line 2

In the implementation, the Carp module does the heavy work, through
'longmess()'. The actual implementation sets the signal hooks
$SIG{__WARN__} and $SIG{__DIE__} to emit the stack backtraces.

Also, all uses of 'carp' and 'croak' are made verbose, behaving like
'cluck' and 'confess'.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README
%license LICENSE

%changelog
* Tue Aug 14 2018 coolo@suse.com
- updated to 0.16
  see /usr/share/doc/packages/perl-Carp-Always/Changes
* Mon Nov 25 2013 coolo@suse.com
- updated to 0.13
  - Test::More and Test::Base go to TEST_REQUIRES
  - Test::Pod and Test::Pod::Coverage as author tests
    (solves RT#87423)
* Mon Jun  3 2013 coolo@suse.com
- updated to 0.12
  - fix failing t/pod.t due to bad encoding (CPAN #77656)
  - fix test failure with Carp 1.25+ RT#75320 [thanks ANDK and greeneg]
  - Test::Base is required in BUILD (otherwise we haven't tested anything)
* Tue Oct 25 2011 tabraham@novell.com
- updated to 0.10
  * fix typo in POD RT#68793 (also reported by Kai Moonbourn)
  * Carp:Always ate part of errors like 'foo at bar' RT#57385
    (fix borrowed from Carp::Always::Color)
  * deal with non-string exceptions (borrowed from Carp:Always:Color
    as well)
* Fri Jan 14 2011 coolo@novell.com
- initial package 0.09
  * created by cpanspec 1.78.03
